@@ -27,10 +27,6 @@
 #include "util.h"
 #include "zone_register.h"
 
-#if LIBDNS_VERSION_MAJOR < 1600
-#define dns_name_copynf(src, dst) dns_name_copy((src), (dst), NULL)
-#endif
-
 /**
  * Convert LDAP DN to absolute DNS names.
  *
