@@ -30,7 +30,6 @@
 #include "dyndb-config.h"
 
 #if LIBDNS_VERSION_MAJOR < 1600
-#define dns_name_copynf(src, dst) dns_name_copy((src), (dst), NULL)
 #define REFCOUNT_CAST(n) ((typeof(((isc_refcount_t *)0)->refs)) (n))
 
 /* Static assert is not provided yet, copy from 9.16 */
@@ -495,7 +494,7 @@ mldap_iter_deadnodes_next(mldapdb_t *mldap, metadb_iter_t **iterp,
 	isc_result_t result;
 	dns_dbnode_t *rbt_node = NULL;
 	metadb_iter_t *iter = NULL;
-	uint32_t node_generation;
+	uint32_t node_generation = 0;
 	uint32_t cur_generation;
 	metadb_node_t metadb_node;
 	DECLARE_BUFFERED_NAME(name);
