@@ -24,6 +24,15 @@
 #include "types.h"
 #include "ldap_helper.h"
 #include "zone_register.h"
+#include "dyndb-config.h"
+
+#if LIBDNS_VERSION_MAJOR < 1600
+#define cfg_parse_buffer cfg_parse_buffer4
+#define cfg_print_grammar(cfg_type_conf, flags, cfg_printer, log_buf) cfg_print_grammar((cfg_type_conf), (cfg_printer), (log_buf))
+typedef dns_name_t       node_name_t;
+#else
+typedef const dns_name_t node_name_t;
+#endif
 
 bool verbose_checks = false; /* log each failure in CHECK() macro */
 
@@ -279,9 +288,12 @@ set_value(isc_mem_t *mctx, const settings_set_t *set, setting_t *setting,
 		len = strlen(value) + 1;
 		if (setting->is_dynamic)
 			isc_mem_free(mctx, setting->value.value_char);
-		CHECKED_MEM_ALLOCATE(mctx, setting->value.value_char, len);
+		setting->value.value_char = isc_mem_allocate(mctx, len);
 		setting->is_dynamic = true;
-		CHECK(isc_string_copy(setting->value.value_char, len, value));
+		/* isc_string_copy has been removed */
+		if (strlcpy(setting->value.value_char, value, len) >= len) {
+			CLEANUP_WITH(ISC_R_NOSPACE);
+		}
 		break;
 
 	case ST_UNSIGNED_INTEGER:
@@ -481,37 +493,30 @@ settings_set_create(isc_mem_t *mctx, const setting_t default_settings[],
 		    const unsigned int default_set_length, const char *set_name,
 		    const settings_set_t *const parent_set,
 		    settings_set_t **target) {
-	isc_result_t result = ISC_R_FAILURE;
 	settings_set_t *new_set = NULL;
 
 	REQUIRE(target != NULL && *target == NULL);
 	REQUIRE(default_settings != NULL);
 	REQUIRE(default_set_length > 0);
 
-	CHECKED_MEM_ALLOCATE(mctx, new_set, default_set_length);
+	new_set = isc_mem_allocate(mctx, default_set_length);
 	ZERO_PTR(new_set);
 	isc_mem_attach(mctx, &new_set->mctx);
 
-	CHECKED_MEM_GET_PTR(mctx, new_set->lock);
-	result = isc_mutex_init(new_set->lock);
-	INSIST(result == ISC_R_SUCCESS);
+	new_set->lock = isc_mem_get(mctx, sizeof(*(new_set->lock)));
+	/* isc_mutex_init failures are now fatal */
+	isc_mutex_init(new_set->lock);
 
 	new_set->parent_set = parent_set;
 
-	CHECKED_MEM_ALLOCATE(mctx, new_set->first_setting, default_set_length);
+	new_set->first_setting = isc_mem_allocate(mctx, default_set_length);
 	memcpy(new_set->first_setting, default_settings, default_set_length);
 
-	CHECKED_MEM_ALLOCATE(mctx, new_set->name, strlen(set_name) + 1);
+	new_set->name = isc_mem_allocate(mctx, strlen(set_name) + 1);
 	strcpy(new_set->name, set_name);
 
 	*target = new_set;
-	result = ISC_R_SUCCESS;
-
-cleanup:
-	if (result != ISC_R_SUCCESS)
-		settings_set_free(&new_set);
-
-	return result;
+	return ISC_R_SUCCESS;
 }
 
 /**
@@ -531,7 +536,8 @@ settings_set_free(settings_set_t **set) {
 		mctx = (*set)->mctx;
 
 		if ((*set)->lock != NULL) {
-			DESTROYLOCK((*set)->lock);
+			/* isc_mutex_destroy failures are now fatal */
+			isc_mutex_destroy((*set)->lock);
 			SAFE_MEM_PUT_PTR(mctx, (*set)->lock);
 		}
 
@@ -577,7 +583,7 @@ cfg_printer(void *closure, const char *text, int textlen) {
 static isc_result_t
 settings_set_fill(const cfg_obj_t *config, settings_set_t *set)
 {
-	isc_result_t result;
+	isc_result_t result = ISC_R_SUCCESS;
 	setting_t *setting;
 	isc_buffer_t *buf_value = NULL;
 	const cfg_obj_t *cfg_value;
@@ -585,7 +591,8 @@ settings_set_fill(const cfg_obj_t *config, settings_set_t *set)
 
 	REQUIRE(cfg_obj_ismap(config) == true);
 
-	CHECK(isc_buffer_allocate(set->mctx, &buf_value, ISC_BUFFER_INCR));
+	/* isc_buffer_allocate can no longer fail */
+	isc_buffer_allocate(set->mctx, &buf_value, ISC_BUFFER_INCR);
 	isc_buffer_setautorealloc(buf_value, true);
 
 	for (setting = set->first_setting;
@@ -678,7 +685,8 @@ setting_set_parse_conf(isc_mem_t *mctx, const char *name,
 
 	REQUIRE(parameters != NULL);
 
-	CHECK(isc_buffer_allocate(mctx, &log_buf, ISC_BUFFER_INCR));
+	/* isc_buffer_allocate can no longer fail */
+	isc_buffer_allocate(mctx, &log_buf, ISC_BUFFER_INCR);
 	isc_buffer_setautorealloc(log_buf, true);
 
 	len = strlen(parameters);
@@ -686,8 +694,8 @@ setting_set_parse_conf(isc_mem_t *mctx, const char *name,
 	isc_buffer_add(&in_buf, len);
 
 	CHECK(cfg_parser_create(mctx, dns_lctx, &parser));
-	result = cfg_parse_buffer2(parser, &in_buf, name, cfg_type_conf,
-				   &config);
+	result = cfg_parse_buffer(parser, &in_buf, name, 0, cfg_type_conf, 0,
+				  &config);
 	if (result == ISC_R_SUCCESS) {
 		cfg_printx(config, CFG_PRINTER_XKEY, cfg_printer, log_buf);
 		cfg_obj_log(config, dns_lctx, ISC_LOG_DEBUG(10),
@@ -700,7 +708,7 @@ setting_set_parse_conf(isc_mem_t *mctx, const char *name,
 		log_error("configuration for dyndb instance '%s' "
 			  "(starting in file %s on line %lu) is invalid",
 			  name, file, line);
-		cfg_print_grammar(cfg_type_conf, cfg_printer, log_buf);
+		cfg_print_grammar(cfg_type_conf, 0, cfg_printer, log_buf);
 		log_info("expected grammar:\n"
 			 "%.*s", isc_buffer_usedlength(log_buf),
 			 (char *)isc_buffer_base(log_buf));
